%%------------------------------------------------ODORS EVALUATION FUNCTION
function OdorUS()


% odor rating: selection of US odor % modified on the 14.01.2016 by YS
% last modified on the 09.05.2016
% 19 odors (8 'appetitive'; 10 'positive'; 2 empty)

% Each trial takes 20 s but it could be longer (not shorter) if the self
% paced response takes long

ShowHideWinTaskbarMex(1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PRELIMINATY STUFF
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

AssertOpenGL; % Check for Opengl compatibility, abort otherwise:
KbName('UnifyKeyNames');% Make sure keyboard mapping is the same on all supported operating systems (% Apple MacOS/X, MS-Windows and GNU/Linux)
KbCheck; WaitSecs(0.1); GetSecs;% Do dummy calls to GetSecs, WaitSecs, KbCheck to make sure they are loaded and ready when we need them - without delays

%-------------------------------------------------RANDOM NUMBERS GENERATION
s = RandStream('mt19937ar','seed',sum(100*clock));
% RandStream.setDefaultStream(s); %For MATLAB 2009
RandStream.setGlobalStream(s); %For MATLAB 2011a or higher

%%%%%%%%%%%%%%%%%% prepare experiment structure %%%%%%%%%%%%%%%%%%%%%%%%%%%

var.experimentalSetup = str2num(input('Are the pyhsiological setup and the olfactometer installed (1= yes or 0 = no) ','s'));
%check that var.experimentalSetup is either 0 or 1
if ~any(var.experimentalSetup == 0:1)
    error('Must provide a number of 0 (= Physiological setup and olfactomer NOT INSTALLED) or 1 (= Physiological setup and olfactomer INSTALLED)');
end
var.instruction = str2num(input('Play the instructions? (1 = French or 2 = English) ','s'));
%check that var.instruction is either 1 or 2
if ~any(var.instruction == 1:2)
    error('Must provide a number of 1 (= French) or 2 (= English) for the instruction language');
end

%var.day = str2num(input('What day session ? (1 = first day or 2 = second day) ','s'));

var.filepath = MakePathStruct();
cd(var.filepath.scripts);

%%%%%%%%%%%%%%%%   Collect Participant and Day    %%%%%%%%%%%%%%%%%%%%%%%%

% Create the file where storing the results
[resultFile,participantID] = createResultFile(var);
var.participantID = participantID;
resultFile = fullfile (var.filepath.data, resultFile); %to save the the file in the data directory

% Date and time informations
data.SubDate = datestr(now, 24); % Use datestr to get the date in the format dd/mm/yyyy
data.SubHour = datestr(now, 13); % Use datestr to get the time in the format hh:mm:ss

save(resultFile,'data');% We save immediately the session's informations

%%%%%%%%%%%%%%%%%%%    Load and radonimze list     %%%%%%%%%%%%%%%%%%%%%%%%
% Load variables
% var.responseTimeWindow = 5; % this variable is for the VAS scale (ratingOdor function) if the participant did not respond after the VAS has appeared, then the scripts keeps going

% triggers coding system

% phase:
trig.trialStart = 2;
trig.vanOpen = 30;
trig.sniffSignal = 100; %60;
trig.trialEnd = 200;
trig.experimentEnd = 255; %CH1 to 8

% odors:
% left side of the olfactometer
trig.odorL_1 = 5; %chocolate
trig.odorL_2 = 7; %strawberry
trig.odorL_3 = 9; %speculoos
trig.odorL_4 = 11; %caramel
trig.odorL_5 = 13; %lavender
trig.odorL_6 = 15; %tiar tahit
trig.odorL_7 = 17; %ariana
trig.odorL_8 = 19; %magnolia grandiflora
% trig.odorL_9 = 21;
% trig.odorL_10 = 23;
% trig.odorL_11 = 25;
% trig.odorL_12 = 27;
% trig.odorL_13 = 29;

%trig.target = 2;
trig.emptyL = 3;
trig.emptyR = 4;

trig.odorR_1 = 2; %peach NP
trig.odorR_2 = 6; %linalol
trig.odorR_3 = 8; %tutti frutti
trig.odorR_4 = 10; %geraniol
trig.odorR_5 = 12; %pipol
trig.odorR_6 = 14; %green tea
trig.odorR_7 = 16; %pin ABS
trig.odorR_8 = 18; %aladinate
trig.odorR_9 = 20; %galbex
% trig.odorR_10 = 22;
% trig.odorR_11 = 24;
% trig.odorR_12 = 26;
% trig.odorR_13 = 28;

% trigger vector
% trig.odors = [trig.odorL_1; trig.odorL_2; trig.odorL_3; trig.odorL_4; trig.odorL_5; trig.odorL_6; trig.odorL_7;...
%     trig.odorL_8; trig.odorL_9; trig.odorL_10; trig.odorL_11; trig.odorL_12; trig.odorL_13;...
%     trig.emptyL;...
%     trig.odorR_1; trig.odorR_2; trig.odorR_3; trig.odorR_4; trig.odorR_5; trig.odorR_6; trig.odorR_7;...
%     trig.odorR_8; trig.odorR_9; trig.odorR_10; trig.odorR_11; trig.odorR_12; trig.odorR_13;...
%     trig.emptyR];

trig.odorsL = [trig.odorL_1; trig.odorL_2; trig.odorL_3; trig.odorL_4; trig.odorL_5; trig.odorL_6; trig.odorL_7;trig.odorL_8;...
    trig.emptyL];
trig.odorsR = [trig.odorR_1; trig.odorR_2; trig.odorR_3; trig.odorR_4; trig.odorR_5; trig.odorR_6; trig.odorR_7;trig.odorR_8;trig.odorR_9;...
    trig.emptyR];
trig.odors = [trig.odorsL; trig.odorsR];

% identify the target and the empty valve co-ordinate
% target.side = 1;
% target.stim = 1;
% target.trig = trig.target + trig.vanOpen; % van open
% target.label = 'chocolate';
% target.trigSniff =trig.target + trig.sniffSignal;
% target.trigTrialStart = trig.target + trig.trialStart;
% target.trigTrialEnd = trig.target + trig.trialEnd;

empty.sideL = 0; % deliver empty odor on the left side
empty.sideR = 1; % deliver empty odor on the right side
empty.stimL = 9; %4;
empty.stimR = 10; %4;
empty.trigL = trig.emptyL + trig.vanOpen; % van open;
empty.trigR = trig.emptyR + trig.vanOpen;
empty.labelL = 'emptyL';
empty.labelR = 'emptyR';
empty.trigSniffL = trig.emptyL + trig.sniffSignal;
empty.trigSniffR = trig.emptyR + trig.sniffSignal;
empty.trigTrialStartL = trig.emptyL + trig.trialStart;
empty.trigTrialStartR = trig.emptyR + trig.trialStart;
empty.trigTrialEndL = trig.emptyL + trig.trialEnd;
empty.trigTrialEndR = trig.emptyR + trig.trialEnd;

% var.sideISI = [0;0;0;0;0;0;0;0;0;0;0;0;0;0;1;1;1;1;1;1;1;1;1;1;1;1;1;1]; %right or left according to the setting %
var.odorLabelL = {'chocolate'; 'strawberry'; 'speculoos';'caramel'; 'lavender'; 'tiare tahite';'ariana';'magnolia grandiflora';... 'odorL9';'odorL10';'odorL11'; 'odorL12'; 'odorL13';...
    empty.labelL};
var.odorLabelR = {'peach NP'; 'linalol'; 'tutti frutti';'geraniol'; 'pipol'; 'green tea';'pin ABS';'aladinate';'galbex';...'odorR10';'odorR11'; 'odorR12'; 'odorR13';...
    empty.labelR};
% var.side = [0;0;0;0;0;0;0;0;0;0;0;0;0;empty.sideL;1;1;1;1;1;1;1;1;1;1;1;1;1;empty.sideR];% 13 odors on the left side and 13 odors on the right side
% var.stim = [1;2;3;5;6;7;8;9;10;11;12;13;14;empty.stimL;1;2;3;5;6;7;8;9;10;11;12;13;14;empty.stimR];% van 4 is used for empty on each side
var.sideL = [0;0;0;0;0;0;0;0;empty.sideL];% 8+1 odors on the left side 
var.sideR = [1;1;1;1;1;1;1;1;1;empty.sideR];% 9+1 odors on the right side
var.stimL = [1;2;3;4;5;6;7;8;empty.stimL];% van 9 is used for empty on left side
var.stimR = [1;2;3;4;5;6;7;8;9;empty.stimR];% van 10 is used for empty on the right side 

var.trig = trig.odors + trig.vanOpen;% triggers for all odors
var.trigL = trig.odorsL + trig.vanOpen;% triggers for odors (left side)
var.trigR = trig.odorsR + trig.vanOpen;% triggers for odors (right side)
var.trigEndL = trig.odorsL + trig.trialEnd;% here it depends on the olfactometer settings
var.trigEndR = trig.odorsR + trig.trialEnd;
var.trigSniffL = trig.odorsL + trig.sniffSignal;% trigger for sniff signal onset
var.trigSniffR = trig.odorsR + trig.sniffSignal;
var.trigTrialStartL = trig.odorsL + trig.trialStart;% trigger for trial begining
var.trigTrialStartR = trig.odorsR + trig.trialStart;

% if var.day == 2% if second day
%     
%     %%%%%%%%%%%%%%%%%%%%%%% select the neutral odor %%%%%%%%%%%%%%%%%%%%%%%
%     % we select odor that is the most neutral and that had a similar
%     % intesity as the target odor
%     
%     [neutralOdor,fileDoesNotExist] = selectNeutralOdor(target.trig,empty.trig,var); % the number refers to the trigger number of chocolate (here = 101) and the empty odor (here = 111)
%     if fileDoesNotExist
%         neutralOdor = str2num(input('The Day 1 file for this participant cannot be find, please enter manually the trigger number (trig.odor+trig.van) of neutral odor (e.g., 36, 38, 40, 42..)','s'));
%     end
%     data.neutralOdor = neutralOdor;
%     save(resultFile,'data','-append'); %save the neutral odor
%     
%     % create the list with neutral odor, chocolate odor and empty van
%     neutralOdorSide = var.side (find(var.trig == data.neutralOdor));
%     var.side = [target.side;neutralOdorSide;empty.side];
%     neutralOdorStim = var.stim (find(var.trig == data.neutralOdor));
%     var.stim = [target.stim;neutralOdorStim;empty.stim];
%     neutralOdorLabel = var.odorLabel_l(find(var.trig == data.neutralOdor));
%     var.odorLabel_l = {target.label;neutralOdorLabel;empty.label};
%     neutralOdorTrigSniff = var.trigSniff(find(var.trig == data.neutralOdor));
%     var.trigSniff = [target.trigSniff;neutralOdorTrigSniff;empty.trigSniff];
%     neutralOdorTrigTrialStart = var.trigTrialStart(find(var.trig == data.neutralOdor));
%     var.trigTrialStart = [target.trigTrialStart;neutralOdorTrigTrialStart;empty.trigTrialStart];
%     var.trig = [target.trig;data.neutralOdor;empty.trig];% trigger for odors, here odor is identified by the function itself
% end



%%%%%%%%%%%%%%%%%%%%%%%%%%  Experimental Set Up %%%%%%%%%%%%%%%%%%%%%%%%%%%

if var.experimentalSetup
    
    % Set comunication with olfactometer
    var.comport = 4; %str2num(input('Enter COMPORT olfactometer ','s'));
    oInit(var.comport,true); % Open Olfacto library
    
    % Set comunication with paralle port
        var.ioObj = SetParallelPort();
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                               OPEN PST
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% PsychDefaultSetup(1);% Here we call some default settings for setting up PTB

screenNumber = max(Screen('Screens')); % check if there are one or two screens and use the second screen when if there is one
%[wPtr,rect]=Screen('OpenWindow',screenNumber, [200 200 200], [20 20 1000 800]); %from the left; from the top; up to the right; up to the bottom
[wPtr,rect]=Screen('OpenWindow',screenNumber, [128 128 128]);
%%%%%%%%%%%%%%%%%%%%% write the instructions %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%write the text for instructions

if var.instruction == 1 %instruction in French
    instruction1 = 'Dans cette partie de l''tude, vous allez accomplir une tche d''valuation d''odeurs.\n\n Dans cette tche, vous sentirez diverses odeurs et vous devrez les valuer  diffrents niveaux \n\n sur des chelles allant de 0  100 \n\n\n\n\n\n\n\n Appuyez sur une touche pour continuer';
    instruction2 = 'Attention !!! \n\n La perception de certaines proprits des odeurs peut varier selon le moment\n\n et les conditions dans lesquelles l''odeur est prsente. Pour cette raison, nous vous \n\n demandons d''valuer les odeurs en vous focalisant sur la perception\n\n que vous avez de l''odeur ici et maintenant.\n\n\n\n\n\n\n\n Appuyez sur une touche pour commencer la tche d''valuation des odeurs';
    wait = 'PAUSE \n\n\n\n Veuillez attendre l''exprimentateur';
    asterix = '*';
    cross = '+';
    one = '1';
    two = '2';
    three = '3';
    End = 'La premire phase de l''tude est termine, merci !';
    attention = 'Attention !!';
    
    % and variables for the VAS scales (see auxiliary function)
    var.howPleasant = 'A quel point avez-vous trouv l''odeur agrable?';
    var.anchorMinPleasant = 'Extrmement dsagrable';
    var.anchorMaxPleasant = 'Extrmement agrable';
    var.howIntense = 'A quel point avez-vous trouv l''odeur intense?';
    var.anchorMinIntense = 'Pas perue';
    var.anchorMaxIntense = 'Extrmement forte';
    var.pressToContinue = 'Appuyez sur la barre d''espace pour confirmer et continuer';
    var.tooLong = 'Rponse trop lente';
    
elseif var.instruction == 2 %instruction in English
    instruction1 = 'In this part of the experiment, you will perform an odor evaluation task.\n\n In this task, you will smell different kinds of odors and you will evaluate \n\n them on different scales going from 0 to 100.\n\n\n\n\n\n\n\n Press a button to continue';
    instruction2 = 'Beware !!!\n\n The perception of the odors can vary across time and the conditions\n\n in which they odors are perceived.\n\n For this reason, we ask you to evaluate the odors, by focusing on\n\n the perception you have here and now.\n\n\n\n\n\n\n\n Press a button to start the odor evaluation task';
    wait = 'PAUSE \n\n\n\n Please wait for the experimenter';
    asterix = '*';
    cross = '+';
    one = '1';
    two = '2';
    three = '3';
    End = 'The first part of the experiment is over, thank you !';
    attention = 'Attention !!';
    
    % and variables for the VAS scales (see auxiliary function)
    var.howPleasant = 'How pleasant was the odor?';
    var.anchorMinPleasant = 'Extremely unpleasant';
    var.anchorMaxPleasant = 'Extremely pleasant';
    var.howIntense = 'How intense was the odor?';
    var.anchorMinIntense = 'Not perceived';
    var.anchorMaxIntense = 'Extremely strong';
    var.pressToContinue = 'Press the space bar to confirm and continue';
    var.tooLong = 'Too slow';
end

HideCursor;

showInstructionSimple (wPtr,instruction1);
WaitSecs(2);
KbWait(-1);

showInstructionSimple (wPtr, instruction2);
WaitSecs(2);
KbWait(-1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%% MRI starts %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% % Put up a "Get Ready" screen until the experimenter presses the space button.
% showInstructionSimple (wPtr,wait);
% triggerscanner = 0;
% WaitSecs(0.4);
% 
% while ~triggerscanner
%     [down secs key d] = KbCheck(-1);
%     if (down == 1)
%         if strcmp('5%',KbName(key))
%             triggerscanner = 1;
%         end
%     end
%     WaitSecs(.01);
% end


%%%%%%%%%%%%%%%%%%%%%%%%%%%% set timing variables%%%%%%%%%%%%%%%%%%%%%%%%%%
var.time = GetSecs(); % absolute reference of the experiment beginning
var.ref_end = 0; % var.ref_end is continually updated as the end time for various functions to compute the drift and adjust the ITI

var.ref_end = var.ref_end + 2.0;
data.attention_duration = showInstruction(wPtr,attention,var);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                        EXPERIMENTAL PROCEDURE                           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% if var.day == 1
var.repetitions = 1;% determine the amount of time a each odor will be repeteated
var.lengthBlock = 1; %define how many
% elseif var.day == 2
%     var.repetitions = 1;% determine the amount of time a each odor will be repeteated
%     var.lengthBlock = 1; %define how many
% end

% initialize variables
nTrial = 0;  % set le compteur to 0

var.lines = (length(var.trig)*var.repetitions*var.lengthBlock); %to initialize the variables

data.liking = NaN (var.lines,1);
data.intensity = NaN (var.lines,1);
data.odorLabel = cell (var.lines,1);
data.tTrialStart = NaN (var.lines,1);
data.tTrialEnd = NaN (var.lines,1);
data.odorTrigger = NaN (var.lines,1);
data.odorSide = NaN (var.lines,1);
data.odorStim = NaN (var.lines,1);
data.Trial = NaN (var.lines,1);

%timing data: onsets
data.tValveOpen = NaN (var.lines,1);
data.tValveClose = NaN (var.lines,1);
data.sniffSignalOnset = NaN (var.lines,1);
data.likingOnset = NaN (var.lines,1);
data.intensityOnset = NaN (var.lines,1);

%timing data: durations
data.duration.SendTriggerStart= NaN (var.lines,1);
data.duration.count3= NaN (var.lines,1);
data.duration.count2= NaN (var.lines,1);
data.duration.oCommitOdor= NaN (var.lines,1);
data.duration.count1= NaN (var.lines,1);
data.duration.asterix1= NaN (var.lines,1);
data.duration.oCommitISI= NaN (var.lines,1);
data.duration.SendTriggerSniff= NaN (var.lines,1);
data.duration.asterix2= NaN (var.lines,1);
data.drift = NaN (var.lines,1);
data.duration.jitter= NaN (var.lines,1);
data.duration.Liking = NaN (var.lines,1);
data.duration.cleanKeyboardMemory1= NaN (var.lines,1);
data.duration.IQCross = NaN (var.lines,1);
data.duration.Intensity = NaN (var.lines,1);
data.duration.cleanKeyboardMemory2= NaN (var.lines,1);
data.duration.ITI = NaN (var.lines,1);% presenting a slide on the graphical interface variable and non-negletable time we will adjust the ITI to recalibrating for this time.

for r = 1: var.repetitions  

    
% We randomize the odor order presentation after every serie repetition
randomIndexL = randperm(length(var.trigL));% randomization for left side

var.stimL = var.stimL(randomIndexL);
var.sideL = var.sideL(randomIndexL);
var.trigL = var.trigL(randomIndexL);
var.trigEndL = var.trigEndL(randomIndexL);
var.odorLabelL = var.odorLabelL(randomIndexL);
var.trigSniffL = var.trigSniffL(randomIndexL);
var.trigTrialStartL = var.trigTrialStartL(randomIndexL);

randomIndexR = randperm(length(var.trigR));% randomization for right side

var.stimR = var.stimR(randomIndexR);
var.sideR = var.sideR(randomIndexR);
var.trigR = var.trigR(randomIndexR);
var.trigEndR = var.trigEndR(randomIndexR);
var.odorLabelR = var.odorLabelR(randomIndexR);
var.trigSniffR = var.trigSniffR(randomIndexR);
var.trigTrialStartR = var.trigTrialStartR(randomIndexR);

if mod(var.participantID, 2) == 0 %if the participant ID is even
    var.stim = [var.stimR; var.stimL];
    var.side = [var.sideR; var.sideL];
    var.trig = [var.trigR; var.trigL];
    var.trigEnd = [var.trigEndR; var.trigEndL];
    var.odorLabel_l = [var.odorLabelR; var.odorLabelL];
    var.trigSniff = [var.trigSniffR; var.trigSniffL];
    var.trigTrialStart = [var.trigTrialStartR; var.trigTrialStartL];
else
    var.stim = [var.stimL; var.stimR];
    var.side = [var.sideL; var.sideR];
    var.trig = [var.trigL; var.trigR];
    var.trigEnd = [var.trigEndL; var.trigEndR];
    var.odorLabel_l = [var.odorLabelL; var.odorLabelR];
    var.trigSniff = [var.trigSniffL; var.trigSniffR];
    var.trigTrialStart = [var.trigTrialStartL; var.trigTrialStartR];
end

    for i = 1:length(var.trig);
       
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % PAUSE during odor evaluation to change between left (or right)
        % and right (or left) canula
        if mod(var.participantID, 2) == 0 %if the participant ID is even
            startPause = GetSecs; %compute start time of the break to update var.ref_end
            if i == length(var.trigR) + 1 %once all odors on the right side have been evaluated
                                
                showInstructionSimple(wPtr, wait);
                WaitToContinue = 0;
                
                while WaitToContinue == 0 % while waiting for the experimenter, display text on the screen
                    [~, ~, keyCode] = KbCheck;
                    if keyCode(KbName('5%')) % press 5 to end the break and continue the experiment
                        WaitToContinue = 1;
                    end
                end
                showInstructionSimple(wPtr, cross);
                WaitSecs(4);
                var.ref_end = var.ref_end + (GetSecs-startPause); % update var.ref_end
            end
        else
            startPause = GetSecs; %compute start time of the break to update var.ref_end
            if i == length(var.trigL) + 1 %once all odors on the left side have been evaluated
                               
                showInstructionSimple(wPtr, wait);
                WaitToContinue = 0;
                WaitSecs(4);
                
                while WaitToContinue == 0 % while waiting for the experimenter, display text on the screen
                    [~, ~, keyCode] = KbCheck;
                    if keyCode(KbName('5%')) % press 5 to end the break and continue the experiment
                        WaitToContinue = 1;
                    end
                end
                showInstructionSimple(wPtr, cross);
                WaitSecs(4);
                var.ref_end = var.ref_end + (GetSecs-startPause); % update var.ref_end
            end
        end
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
        for mb = 1:var.lengthBlock; % MiniBlock: three repetion of the same odor
            
            nTrial = nTrial + 1;
            data.Trial (nTrial,1) = nTrial;
            [time,SendTrigger_t] = SendTrigger(var.trigTrialStart(i),var); % send trigger and record time
            data.tTrialStart(nTrial,1) = time;
            data.duration.SendTriggerStart(nTrial,1)= SendTrigger_t;
            data.odorLabel (nTrial) = var.odorLabel_l(i); % identify the label of odor that is released
            data.odorTrigger (nTrial) = var.trig (i);% identify the trigger of odor that is released
            data.odorSide (nTrial) = var.side (i);
            data.odorStim (nTrial) = var.stim (i);
            if var.experimentalSetup
                oStimulus(var.side (i),var.stim (i));% select odor
            end
            
            %%%%%%%%%%%%%%%%%% Count Down three two %%%%%%%%%%%%%%%%%%%%%%%
            var.ref_end = var.ref_end + 1.0; % count 3 for 1 s
            data.duration.count3(nTrial,1) = showInstruction (wPtr, three,var); %3
            
            var.ref_end = var.ref_end + 1.0; % count 2 for 1 s
            data.duration.count2(nTrial,1) = showInstruction (wPtr, two,var); %2
            
%             %%%%%%%%%% Odor Release (anticipated for the scanner) %%%%%%%%%
%             if var.day == 2;
%             [tValve, oCommit_t] = SendOdor (var.trig (i),var);% Odor Release and record time
%             data.tValveOpen (nTrial,1) = tValve;
%             data.duration.oCommitOdor(nTrial,1) = oCommit_t; % record how long send odor takes
%             var.ref_end = var.ref_end + data.duration.oCommitOdor(nTrial,1);% and update var.ref_end
%             end
            %%%%%%%%%%%%%%%%%%%%%%%%%%% Count Down one %%%%%%%%%%%%%%%%%%%%
            var.ref_end = var.ref_end + 1.0; % count 1 for 1 s
            data.duration.count1(nTrial,1) = showInstruction (wPtr, one,var); %1
            
            %%%%%%%%%%%%%%%%%%%%%%%%%%%% Odor Release (day 1)  %%%%%%%%%%%%
%             if var.day == 1;
            [tValve, oCommit_t] = SendOdor (var.trig (i),var);% Odor Release and record time
            data.tValveOpen (nTrial,1) = tValve;
            data.duration.oCommitOdor(nTrial,1) = oCommit_t; % record how long send odor takes
            var.ref_end = var.ref_end + data.duration.oCommitOdor(nTrial,1);% and update var.ref_end
            WaitSecs(0.5);
%             end     
        
            %%%%%%%%%%%%%%%%%%%%%%%%%%% Sniffing signal %%%%%%%%%%%%%%%%%%%
            [time,SendTrigger_t] = SendTrigger (var.trigSniff(i),var);% send trigger and record timing variables
            data.sniffSignalOnset(nTrial,1) = time;
            data.duration.SendTriggerSniff(nTrial,1) = SendTrigger_t; % how long the function takes
            var.ref_end = var.ref_end + data.duration.SendTriggerSniff(nTrial,1);% update var.ref_end because it take 30 ms to send a trigger
            
%             if var.day == 2;
%             var.ref_end = var.ref_end + 1.5;%% attention this might be change in order to have an effective 2.5 s according to the odor molecules
%             end
            
%             if var.day == 1;
            var.ref_end = var.ref_end + 1;%% attention this might be change in order to have an effective 1.5 s
%             end
            
            data.duration.asterix1(nTrial,1) = showInstruction (wPtr,asterix,var); % sniff
            
            %%%%%%%%%%%%%%%%%%%%%%%%%%%% Close Odor %%%%%%%%%%%%%%%%%%%%%%%
            if var.experimentalSetup
                if var.side(i) == 0
                    var.sideISI = 0;
                elseif var.side(i) == 1
                    var.sideISI = 1;
                end
                oInterStimulus(var.sideISI); % select ISI air
            end
            
            [tValve, oCommit_t] = SendOdor(var.trigEnd(i),var);% release ISI air and record time
            data.tValveClose(nTrial,1) = tValve;
            data.duration.oCommitISI(nTrial,1)= oCommit_t;
            var.ref_end = var.ref_end + data.duration.oCommitISI(nTrial,1);
            
            %%%%%%%%%%%%%%%%%%% Sniffing signal continue %%%%%%%%%%%%%%%%%%
            var.ref_end = var.ref_end + 1.0;
            data.duration.asterix2(nTrial,1)= showInstruction (wPtr,asterix,var); % sniff
            
            data.drift(nTrial,1) = GetSecs()-var.time - data.tTrialStart(nTrial,1)-5.5; % until here the timing is fixed thus we can cumpute here the drift
            
            %%%%%%%%%%%%%%%%%%% Break before questions %%%%%%%%%%%%%%%%%%%%
            tjietter = randsample([0.8:1,1:1.2],1); % randomize jitter between 0.8 and 1.2
            var.ref_end = var.ref_end + tjietter;
            data.duration.jitter(nTrial,1)=showInstruction (wPtr,cross,var);
            
            %%%%%%%%%%%%%%%%%%%%%%%%%%%% Pleasantness %%%%%%%%%%%%%%%%%%%%%
            l1 = GetSecs;
            data.likingOnset(nTrial,1) = time;
            data.liking (nTrial,1) = ratingOdor(var.howPleasant,var.anchorMinPleasant,var.anchorMaxPleasant,wPtr,rect,var);
            l2 = GetSecs;
            data.duration.cleanKeyboardMemory1(nTrial,1) = cleanKeyboardMemory();
            data.duration.Liking (nTrial,1) = (l2-l1)+ data.duration.cleanKeyboardMemory1(nTrial,1);%+data.duration.SendTriggerPlesantnessQ(nTrial,1); % timing of the liking evaluation
            var.ref_end = var.ref_end + data.duration.Liking (nTrial,1);
            
            %%%%%%%%%%%%%%%%%%%%%%%%%% InterQuestionBreak %%%%%%%%%%%%%%%%%
            var.ref_end = var.ref_end + 0.5;
            data.duration.IQCross(nTrial,1)= showInstruction (wPtr, cross,var); % interquestion cross timing
            
            %%%%%%%%%%%%%%%%%%%%%%%%%%%% Intensity %%%%%%%%%%%%%%%%%%%%%%%%
            I1 = GetSecs;
            data.intensityOnset(nTrial,1) = time;
            data.intensity (nTrial,1) = ratingOdor(var.howIntense,var.anchorMinIntense,var.anchorMaxIntense,wPtr,rect,var);
            I2 = GetSecs;
            data.duration.cleanKeyboardMemory2(nTrial,1) = cleanKeyboardMemory();
            data.duration.Intensity(nTrial,1) = (I2 -I1)+ data.duration.cleanKeyboardMemory2(nTrial,1);%+data.duration.SendTriggerIntensityQ (nTrial,1);
            var.ref_end = var.ref_end + data.duration.Intensity(nTrial,1);
            
            %%%%%%%%%%%%%%%%%%%%%%% ITI %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            ITI = 15 - data.duration.jitter(nTrial,1) - data.duration.Liking (nTrial)- data.duration.IQCross(nTrial,1) - data.duration.Intensity(nTrial) - data.drift(nTrial); %ITI 12.5 initially
            
            if ITI < 0
                ITI = 0.5;
            end
            
            var.ref_end = var.ref_end + ITI;
            data.duration.ITI(nTrial,1) = showInstruction (wPtr, cross,var);
            
            %%%%%%%%%%%%%%%%%%%%%%%%%%% Save Results %%%%%%%%%%%%%%%%%%%%%%
            data.tTrialEnd(nTrial,1) = GetSecs-var.time;
            save(resultFile,'data','-append')
            
        end
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                           END OF THE EXPERIMENT
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
showInstruction (wPtr,End,var);
WaitSecs(0.4);
KbWait(-1);

if var.experimentalSetup
    oClose;
end

ShowCursor;
Screen('CloseAll');

%%--------------------------------------------------------US ODOR SELECTION
odorNumber = 19; emptyOdorNumber = 2;
var.odorNumber = odorNumber - emptyOdorNumber; %number of odors (minus left and right empty odors) presented during the first phase of the experiment

emptyOdor.trigL = 33;
emptyOdor.stimL = 9; %4;
emptyOdor.labelL = 'emptyL';
emptyOdor.trigR = 34;
emptyOdor.stimR = 10; %4;
emptyOdor.labelR = 'emptyR';

[selectedOdorUS, ~] = selectOdorUS(emptyOdor,var);

fprintf('selected US odor trigger: %d \n', selectedOdorUS.trig);
fprintf('selected US odor stimulation: %d \n', selectedOdorUS.stim);
if mod(selectedOdorUS.trig, 2) == 0 %if the trigger is even (i.e., right side of the olfactometer)
    fprintf('selected US odor side: right \n');
else %if the trigger is odd (i.e., left side of the olfactometer)
    fprintf('selected US odor side: left \n');
end

ShowHideWinTaskbarMex(1);

end